==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/ExportJobRequest.scala <==
package zio.aws.pinpoint.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.{__integer, __string}
import scala.jdk.CollectionConverters.*
final case class ExportJobRequest(
    roleArn: __string,
    s3UrlPrefix: __string,
    segmentId: Option[__string] = None,
    segmentVersion: Option[__integer] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.ExportJobRequest = {
    import ExportJobRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.ExportJobRequest
      .builder()
      .roleArn(__string.unwrap(roleArn): java.lang.String)
      .s3UrlPrefix(__string.unwrap(s3UrlPrefix): java.lang.String)
      .optionallyWith(
        segmentId.map(value => __string.unwrap(value): java.lang.String)
      )(_.segmentId)
      .optionallyWith(
        segmentVersion.map(value => __integer.unwrap(value): Integer)
      )(_.segmentVersion)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.ExportJobRequest.ReadOnly =
    zio.aws.pinpoint.model.ExportJobRequest.wrap(buildAwsValue())
}
object ExportJobRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.ExportJobRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.ExportJobRequest =
      zio.aws.pinpoint.model.ExportJobRequest(
        roleArn,
        s3UrlPrefix,
        segmentId.map(value => value),
        segmentVersion.map(value => value)
      )
    def roleArn: __string
    def s3UrlPrefix: __string
    def segmentId: Option[__string]
    def segmentVersion: Option[__integer]
    def getRoleArn: ZIO[Any, Nothing, __string] = ZIO.succeed(roleArn)
    def getS3UrlPrefix: ZIO[Any, Nothing, __string] = ZIO.succeed(s3UrlPrefix)
    def getSegmentId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("segmentId", segmentId)
    def getSegmentVersion: ZIO[Any, AwsError, __integer] =
      AwsError.unwrapOptionField("segmentVersion", segmentVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.ExportJobRequest
  ) extends zio.aws.pinpoint.model.ExportJobRequest.ReadOnly {
    override val roleArn: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.roleArn())
    override val s3UrlPrefix: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.s3UrlPrefix())
    override val segmentId: Option[__string] = scala
      .Option(impl.segmentId())
      .map(value => zio.aws.pinpoint.model.primitives.__string(value))
    override val segmentVersion: Option[__integer] = scala
      .Option(impl.segmentVersion())
      .map(value => zio.aws.pinpoint.model.primitives.__integer(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.ExportJobRequest
  ): zio.aws.pinpoint.model.ExportJobRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/ExportJobRequest.scala <==
package zio.aws.pinpoint.model
import zio.prelude.data.Optional
import zio.aws.pinpoint.model.primitives.{__integer, __string}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class ExportJobRequest(
    roleArn: __string,
    s3UrlPrefix: __string,
    segmentId: Optional[__string] = Optional.Absent,
    segmentVersion: Optional[__integer] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.ExportJobRequest = {
    import ExportJobRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.ExportJobRequest
      .builder()
      .roleArn(roleArn: java.lang.String)
      .s3UrlPrefix(s3UrlPrefix: java.lang.String)
      .optionallyWith(segmentId.map(value => value: java.lang.String))(
        _.segmentId
      )
      .optionallyWith(segmentVersion.map(value => value: Integer))(
        _.segmentVersion
      )
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.ExportJobRequest.ReadOnly =
    zio.aws.pinpoint.model.ExportJobRequest.wrap(buildAwsValue())
}
object ExportJobRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.ExportJobRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.ExportJobRequest =
      zio.aws.pinpoint.model.ExportJobRequest(
        roleArn,
        s3UrlPrefix,
        segmentId.map(value => value),
        segmentVersion.map(value => value)
      )
    def roleArn: __string
    def s3UrlPrefix: __string
    def segmentId: Optional[__string]
    def segmentVersion: Optional[__integer]
    def getRoleArn: ZIO[Any, Nothing, __string] = ZIO.succeed(roleArn)
    def getS3UrlPrefix: ZIO[Any, Nothing, __string] = ZIO.succeed(s3UrlPrefix)
    def getSegmentId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("segmentId", segmentId)
    def getSegmentVersion: ZIO[Any, AwsError, __integer] =
      AwsError.unwrapOptionField("segmentVersion", segmentVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.ExportJobRequest
  ) extends zio.aws.pinpoint.model.ExportJobRequest.ReadOnly {
    override val roleArn: __string = impl.roleArn(): __string
    override val s3UrlPrefix: __string = impl.s3UrlPrefix(): __string
    override val segmentId: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.segmentId())
      .map(value => value: __string)
    override val segmentVersion: Optional[__integer] = zio.aws.core.internal
      .optionalFromNullable(impl.segmentVersion())
      .map(value => value: __integer)
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.ExportJobRequest
  ): zio.aws.pinpoint.model.ExportJobRequest.ReadOnly = new Wrapper(impl)
}
